[gnome-bluetooth: 2/4] settings-widget: Replace HdyColumn by BluetoothHdyColumn



commit 218efaf6e128290869259aeccf3069401f5e8dde
Author: Adrien Plazas <kekun plazas laposte net>
Date:   Tue Feb 5 13:08:36 2019 +0100

    settings-widget: Replace HdyColumn by BluetoothHdyColumn
    
    This fixes the name collision in GNOME Settings.

 lib/bluetooth-settings-widget.c | 10 ++++------
 lib/settings.ui                 |  2 +-
 2 files changed, 5 insertions(+), 7 deletions(-)
---
diff --git a/lib/settings.ui b/lib/settings.ui
index ac944233..60440161 100644
--- a/lib/settings.ui
+++ b/lib/settings.ui
@@ -379,7 +379,7 @@
         <property name="visible">True</property>
         <property name="can_focus">False</property>
         <child>
-          <object class="HdyColumn">
+          <object class="BluetoothHdyColumn">
             <property name="visible">True</property>
             <property name="maximum_width">600</property>
             <property name="linear_growth_width">400</property>


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/lib/bluetooth-settings-widget.c b/lib/bluetooth-settings-widget.c
index ca25c7e4..497c1999 100644
--- a/lib/bluetooth-settings-widget.c
+++ b/lib/bluetooth-settings-widget.c
@@ -25,8 +25,6 @@
 #include <gtk/gtk.h>
 
 #include <glib/gi18n-lib.h>
-#define HANDY_USE_UNSTABLE_API
-#include <handy.h>
 #include <math.h>
 
 #include "bluetooth-client.h"
@@ -39,6 +37,7 @@
 #include "bluetooth-settings-row.h"
 #include "bluetooth-settings-obexpush.h"
 #include "bluetooth-pairing-dialog.h"
+#include "bluetooth-hdy-column.h"
 #include "pin.h"
 
 #define BLUETOOTH_SETTINGS_WIDGET_GET_PRIVATE(obj) \
@@ -1895,11 +1894,10 @@ bluetooth_settings_widget_init (BluetoothSettingsWidget *self)
        GtkWidget *widget;
        GError *error = NULL;
 
        /* This ensures the HdyColumn type is known by GtkBuilder when loading the UI
         * template. This avoids the widget to fail at runtime if the user didn't run
         * hdy_init().
         */
-       g_type_ensure (HDY_TYPE_COLUMN);
+       g_type_ensure (BLUETOOTH_TYPE_HDY_COLUMN);
 
        priv->cancellable = g_cancellable_new ();
        priv->debug = g_getenv ("BLUETOOTH_DEBUG") != NULL;
@@ -1895,11 +1894,10 @@ bluetooth_settings_widget_init (BluetoothSettingsWidget *self)
        GError *error = NULL;
 
-       /* This ensures the HdyColumn type is known by GtkBuilder when loading the UI
-        * template. This avoids the widget to fail at runtime if the user didn't run
-        * hdy_init().
+       /* This ensures the BluetoothHdyColumn type is known by GtkBuilder when
+        * loading the UI template.
         */